==> gcstar_1.1.1.orig.tar.gz: gcstar/lib/gcstar/GCLang/FR/GCModels/GCgames.pm <==
{
    package GCLang::FR::GCModels::GCgames;

    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Collection de jeux vidéo',
        Items => 'Jeux',
        NewItem => 'Nouveau jeu',
    
        Id => 'Identifiant',
        Ean => 'EAN',
        Name => 'Nom',
        Platform => 'Plate-forme',
        Players => 'Nombre de joueurs',
        Released => 'Date de sortie',
        Editor => 'Editeur',
        Developer => 'Développeur',
        Genre => 'Genre',
        Box => 'Boîtier',
        Case => 'Boîte',
        Manual => 'Notice',
        Rating => 'Note',
        Completion => 'Avancement (%)',
        Description => 'Description',
        Codes => 'Codes',
        Code => 'Code',
        Effect => 'Effet',
        Secrets => 'Secrets',
        Screenshots => 'Captures',
        Screenshot1 => '1ère capture',
        Screenshot2 => '2ème capture',
        Comments => 'Commentaires',
        Url => 'Page Web',
        Unlockables => 'Déblocables',
        Unlockable => 'Déblocable',
        Howto => 'Comment débloquer',

        General => 'Général',
        Details => 'Détails',
        Tips => 'Astuces',
        Information => 'Informations',

        FilterRatingSelect => 'Notes au moins égales à...',
     );
}

1;

==> gcstar_1.3.2.orig.tar.gz: gcstar/lib/gcstar/GCLang/FR/GCModels/GCgames.pm <==
{
    package GCLang::FR::GCModels::GCgames;

    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Collection de jeux vidéo',
        #Items => 'Jeux',
        Items => {0 => 'Jeu',
                  1 => 'Jeu',
                  X => 'Jeux'},
        NewItem => 'Nouveau jeu',
    
        Id => 'Identifiant',
        Ean => 'EAN',
        Name => 'Nom',
        Platform => 'Plate-forme',
        Players => 'Nombre de joueurs',
        Released => 'Date de sortie',
        Editor => 'Editeur',
        Developer => 'Développeur',
        Genre => 'Genre',
        Box => 'Boîtier',
        Case => 'Boîte',
        Manual => 'Notice',
        Completion => 'Avancement (%)',
        Executable => 'Executable',
        Description => 'Description',
        Codes => 'Codes',
        Code => 'Code',
        Effect => 'Effet',
        Secrets => 'Secrets',
        Screenshots => 'Captures',
        Screenshot1 => '1ère capture',
        Screenshot2 => '2ème capture',
        Comments => 'Commentaires',
        Url => 'Page Web',
        Unlockables => 'Déblocables',
        Unlockable => 'Déblocable',
        Howto => 'Comment débloquer',

        General => 'Général',
        Details => 'Détails',
        Tips => 'Astuces',
        Information => 'Informations',

        FilterRatingSelect => 'Notes au moins égales à...',
     );
}

1;
